@@ -10,7 +10,7 @@ pub enum Error {
 
     /// A referenced key does not exist
     #[error("Missing non-terminal: {0}")]
-    MissingNonTerminalError(String),
+    UnknownNonTerminalError(String),
 
     /// Internal parser error. This should only happen if the grammar and the
     /// parser are out of sync.
